<?php

namespace Drupal\simple_redirect\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Path\PathValidatorInterface;
use Drupal\Core\Render\Element\PathElement;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class SimpleRedirectConfig.
 *
 * @package Drupal\simple_redirect\Form
 */
class SimpleRedirectConfig extends ConfigFormBase {

  /**
   * The path validator.
   *
   * @var \Drupal\Core\Path\PathValidatorInterface
   */
  protected $pathValidator;

  /**
   * Constructs a SimpleRedirectConfig object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Path\PathValidatorInterface $path_validator
   *   The path validator.
   */
  public function __construct(ConfigFactoryInterface $config_factory, PathValidatorInterface $path_validator) {
    parent::__construct($config_factory);
    $this->pathValidator = $path_validator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('path.validator')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'simple_redirect.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_redirect_config';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('simple_redirect.settings');
    $form['simple_redirect'] = [
      '#type' => 'details',
      '#title' => $this->t('Simple Redirect'),
      '#open' => TRUE,
    ];
    $form['simple_redirect']['user_register'] = [
      '#type' => 'path',
      '#title' => $this->t('After Registration'),
      '#default_value' => $config->get('user_register'),
      '#description' => $this->t('The path that you would like to redirect to after user register. The path of the page should be prefixed with /. Leave blank for redirect to the site front page.'),
      '#convert_path' => PathElement::CONVERT_NONE,
    ];
    $form['simple_redirect']['user_login'] = [
      '#type' => 'path',
      '#title' => $this->t('After Login'),
      '#default_value' => $config->get('user_login'),
      '#description' => $this->t('The path that you would like to redirect to after user login. The path of the page should be prefixed with /. Leave blank for redirect to the site front page.'),
      '#convert_path' => PathElement::CONVERT_NONE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $registration_redirect = $form_state->getValue('user_register');
    if ($registration_redirect && $this->pathValidator->isValid($registration_redirect)) {
      if (substr($registration_redirect, 0, 1) != '/') {
        $form_state->setErrorByName('user_register', $this->t('The path should start with /.'));
      }
    }
    $login_redirect = $form_state->getValue('user_login');
    if ($login_redirect && $this->pathValidator->isValid($login_redirect)) {
      if (substr($login_redirect, 0, 1) != '/') {
        $form_state->setErrorByName('user_login', $this->t('The path should start with /.'));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('simple_redirect.settings')
      ->set('user_register', $form_state->getValue('user_register'))
      ->set('user_login', $form_state->getValue('user_login'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
